@@ -21,13 +21,6 @@
 #' }
 orcid_fundings <- function(orcid, put_code = NULL, 
                            format = "application/json", summary = FALSE, ...) {
-  pth <- if (!summary) {
-    if (is.null(put_code)) "fundings" else "funding"
-  } else {
-    if (is.null(put_code)) {
-      stop("if summary == TRUE, must give 1 or more put_code")
-    }
-    "funding/summary"
-  }
+  pth <- path_picker(put_code, summary, "funding")
   orcid_putcode_helper(pth, orcid, put_code, format, ...)
 }
