@@ -8,27 +8,25 @@
 #'
 #' @examples \dontrun{
 #' # all peer review data
-#' res <- orcid_peer_reviews(orcid = "0000-0002-1642-628X")
-#' res$`0000-0002-1642-628X`
-#' names(res$`0000-0002-1642-628X`)
-#' res$`0000-0002-1642-628X`$`group`
+#' res <- orcid_peer_reviews(orcid = "0000-0001-7678-8656")
+#' res$`0000-0001-7678-8656`
+#' names(res$`0000-0001-7678-8656`)
+#' res$`0000-0001-7678-8656`$`group`
 #' 
 #' # get individual works
 #' orcid_peer_reviews("0000-0003-1444-9135", 75565)
 #' 
 #' # summary
 #' orcid_peer_reviews("0000-0003-1444-9135", 75565, summary = TRUE)
+#' 
+#' # get Journal titles via ISSN's provided in results, using the 
+#' # provided issn_title dataset
+#' x <- orcid_peer_reviews("0000-0001-7678-8656", put_code = "220419")
+#' issn <- strsplit(x[[1]]$`review-group-id`, ":")[[1]][[2]]
+#' issn_title[[issn]]
 #' }
 orcid_peer_reviews <- function(orcid, put_code = NULL, 
                           format = "application/json", summary = FALSE, ...) {
-  
-  pth <- if (!summary) {
-    if (is.null(put_code)) "peer-reviews" else "peer-review"
-  } else {
-    if (is.null(put_code)) {
-      stop("if summary == TRUE, must give 1 or more put_code")
-    }
-    "peer-review/summary"
-  }
+  pth <- path_picker(put_code, summary, "peer-review")
   orcid_putcode_helper(pth, orcid, put_code, format, ...)
 }
