@@ -55,7 +55,6 @@ test_that("orcid qf param works", {
 test_that("orcid fails well", {
   skip_on_cran()
 
-  expect_error(orcid(start = "adsf"), "Server Error")
-  expect_error(orcid(rows = "er"),
-               "The rows parameter must be an integer between 0 and 200")
+  expect_error(orcid(start = "adsf"))
+  expect_error(orcid(rows = "er"))
 })
